==> i18n_plus-0.8.6.tar.gz: lib/i18nLanguageset.dart <==
import 'dart:convert';
import 'package:flutter/widgets.dart';

class Langaugeset {
  Locale locale;
  Map map;

  //Map must be typeOf Map<String, String>
  Langaugeset(Locale locale, Map map) {
    bool checkIfString(List<dynamic> list) {
      bool ans = true;
      for (int x = 0; x < list.length; x++) {
        if (list[x].runtimeType.toString() != "String") {
          return !ans;
        }
      }
      return ans;
    }

    if (checkIfString(map.keys.toList()) &&
        checkIfString(map.values.toList())) {
      this.locale = locale;
      this.map = map;
    } else {
      throw ("Map does not meet requirements. Languageset with Locale: ${locale.scriptCode}");
    }
  }

  ///Returns Languageset from JsonString
  ///Json should look like this:
  ///{
  ///"1":"2",
  ///"2":"2"
  ///}
  ///Key and Value of every element in JsonString has to be typeOf String
  factory Langaugeset.fromJsonString(Locale locale, String jsonFile) {
    Map<String, dynamic> jsonMap = json.decode(jsonFile);

    bool checkIfString(List<dynamic> list) {
      bool ans = true;
      for (int x = 0; x < list.length; x++) {
        if (list[x].runtimeType.toString() != "String") {
          return !ans;
        }
      }
      return ans;
    }

    if (checkIfString(jsonMap.values.toList()) &&
        checkIfString(jsonMap.keys.toList())) {
      return Langaugeset(locale, jsonMap);
    } else {
      throw ("jsonString does not meet requirements. Languageset with Locale: ${locale.scriptCode}");
    }
  }
}

==> i18n_plus-1.1.0.tar.gz: lib/i18nLanguageset.dart <==
import 'dart:convert';
import 'package:flutter/widgets.dart';

class Langaugeset {
  late Locale locale;
  late Map map;

  //Map must be typeOf Map<String, String>
  Langaugeset(Locale locale, Map map) {
    bool checkIfString(List<dynamic> list) {
      bool ans = true;
      for (int x = 0; x < list.length; x++) {
        if (list[x].runtimeType.toString() != "String") {
          return !ans;
        }
      }
      return ans;
    }

    if (checkIfString(map.keys.toList()) &&
        checkIfString(map.values.toList())) {
      this.locale = locale;
      this.map = map;
    } else {
      throw ("Map does not meet requirements. Languageset with Locale: ${locale.scriptCode}");
    }
  }

  ///Returns Languageset from JsonString
  ///Json should look like this:
  ///{
  ///"1":"2",
  ///"2":"2"
  ///}
  ///Key and Value of every element in JsonString has to be typeOf String
  factory Langaugeset.fromJsonString(Locale locale, String jsonFile) {
    Map<String, dynamic>? jsonMap = json.decode(jsonFile);

    bool checkIfString(List<dynamic> list) {
      bool ans = true;
      for (int x = 0; x < list.length; x++) {
        if (list[x].runtimeType.toString() != "String") {
          return !ans;
        }
      }
      return ans;
    }

    if (checkIfString(jsonMap!.values.toList()) &&
        checkIfString(jsonMap.keys.toList())) {
      return Langaugeset(locale, jsonMap);
    } else {
      throw ("jsonString does not meet requirements. Languageset with Locale: ${locale.scriptCode}");
    }
  }
}
